/*
 * BRLTTY - Access software for Unix for a blind person
 *          using a soft Braille terminal
 *
 * Copyright (C) 1995-1998 by The BRLTTY Team, All rights reserved.
 *
 *   Nicolas Pitre <nico@cam.org>
 *   Stphane Doyon <s.doyon@videotron.ca>
 *   Nikhil Nair <nn201@cus.cam.ac.uk>
 * This part from
 *   Roger Butenuth <butenuth@uni-paderborn.de>
 *
 * BRLTTY comes with ABSOLUTELY NO WARRANTY.
 *
 * This is free software, placed under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation.  Please see the file COPYING for details.
 *
 * This software is maintained by Nicolas Pitre <nico@cam.org>.
 */

/*
 * Braille driver for no braille terminal.
 * Useful for testing and for people with speech only.
 * $Id: brl.c,v 1.6 1999/03/07 20:44:20 butenuth Exp $
 */

#define __EXTENSIONS__	/* for termios.h */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <sys/termios.h>
#include <string.h>
#include <assert.h>

#include "../brl.h"
#include "../misc.h"
#include "../config.h"
#include "../config_file.h"

static void closebrl(struct brl_disp *disp);
static void writebrl(struct brl_disp *disp);
static int  readbrl(struct brl_disp *disp, int flag);
static void setbrlstat(struct brl_disp *disp);

/*
 * ----------------------------------------------------------------------
 * Called when library is loaded.
 * ----------------------------------------------------------------------
 */
void _init(void)
{
    fprintf(stderr, "NoBraille driver loaded\n");
}


/*
 * ----------------------------------------------------------------------
 * Called before library is unloaded.
 * ----------------------------------------------------------------------
 */
void _fini(void)
{

}


/*
 * ----------------------------------------------------------------------
 * This function is called before `deamonize', so we can use printf
 * for diagnostic output.
 * Return 0 on success.
 * ----------------------------------------------------------------------
 */
int initbrl(brl_disp_t *disp, brl_drv_t *brl_drv)
{
    int res = 0;

    disp->x = 40;
    disp->y =  1;
    disp->s = 10;
    disp->stat_mode = ST_AlvaStyle;

    disp->disp = malloc(disp->x * disp->y);
    disp->stat = malloc(disp->s);
    if (disp->disp == NULL || disp->stat == NULL) {
	fprintf(stderr, "out of memory\n");
	res = 1;
    }

    disp->closebrl   = closebrl;
    disp->writebrl   = writebrl;
    disp->readbrl    = readbrl;
    disp->setbrlstat = setbrlstat;

    return res;
}


/*
 * ----------------------------------------------------------------------
 * Close Braille display.
 * ----------------------------------------------------------------------
 */
static void closebrl(struct brl_disp *disp)
{
    free(disp->disp);
    free(disp->stat);
    
    memset(disp, 0, sizeof(*disp));
}


/*
 * ----------------------------------------------------------------------
 * Update status cells on braille display
 * ----------------------------------------------------------------------
 */
static void setbrlstat(struct brl_disp *disp)
{
    ;
}


/*
 * ----------------------------------------------------------------------
 * 
 * ----------------------------------------------------------------------
 */
static void writebrl(struct brl_disp *disp)
{
    ;
}


/*
 * ----------------------------------------------------------------------
 * 
 * ----------------------------------------------------------------------
 */
static int readbrl(struct brl_disp *disp, int flag)
{
    return EOF;
}
