/*
 * ======================================================================
 * Dummy synthesizer module, no real output produced.
 * Copyright (C) 1998-1999 Roger Butenuth <butenuth@uni-paderborn.de>
 * This is free software, placed under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation.  Please see the file COPYING for details.
 * For the latest version see:
 * http://www.uni-paderborn.de/cs/heiss/blinux/index.html
 * $Id: dummy_synth.c,v 1.1 1999/03/10 20:37:45 butenuth Exp $
 * ======================================================================
 */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <assert.h>

#include "synthesizer.h"

static int  s_close(synth_t *s);
static int  s_synth(synth_t *s, unsigned char *buffer);
static int  s_flush(synth_t *s);
static int  s_clear(synth_t *s);
static int  s_sync(synth_t *s, sync_par_t par, int timeout);
static int  s_get_param(struct synth_struct *s, synth_par_t par, int *value);
static int  s_set_param(struct synth_struct *s, synth_par_t par, int value);


typedef struct synth_state {
    int  param[S_MAX];
    int  initialized;
} synth_state_t;


static synth_t dummy = {
    NULL,			/* state */
    &languages[LANG_DUMMY],
    "Dummy",
    NULL,			/* library handle */
    s_close,
    s_synth,
    s_flush,
    s_clear,
    s_sync,
    s_get_param,
    s_set_param,
};



/*
 * ----------------------------------------------------------------------
 * General open function.
 * Return 0 on succes, 1 on error.
 * ----------------------------------------------------------------------
 */
synth_t *dummy_synth_open(void)
{
    synth_t       *s = NULL;
    synth_state_t *state = NULL;
    
    s = malloc(sizeof(synth_t));
    if (s == NULL)
	goto failure;
    *s = dummy;
    state = malloc(sizeof(synth_state_t));
    if (s == NULL)
	goto failure;
    memset(state, 0, sizeof(synth_state_t));
    state->initialized = 1;
    s->lib_handle = NULL;
    s->state = state;

    return s;
 failure:
    if (s)
	free(s);
    if (state)
	free(state);
    return NULL;
}


/*
 * ----------------------------------------------------------------------
 * General close.
 * ----------------------------------------------------------------------
 */
static int s_close(synth_t *s)
{

    assert(s->state->initialized);
    s->state->initialized = 0;
   
    free(s->state);
    free(s);
    return 0;
}




/*
 * ----------------------------------------------------------------------
 * 
 * ----------------------------------------------------------------------
 */
static int s_synth(struct synth_struct *s, unsigned char *buffer)
{
    assert(s->state->initialized);

    return 0;
}


/*
 * ----------------------------------------------------------------------
 * 
 * ----------------------------------------------------------------------
 */
static int s_flush(synth_t *s)
{
    assert(s->state->initialized);

    return 0;
}


/*
 * ----------------------------------------------------------------------
 * 
 * ----------------------------------------------------------------------
 */
static int s_clear(synth_t *s)
{
    assert(s->state->initialized);

    return 0;
}


/*
 * ----------------------------------------------------------------------
 * A sync mark is set by sending a string like "@I1\n" (other numbers
 * possible). When it is reached, a line "@I1\n" is sent back.
 * Return 1 when we have reached the mark, 0 when not, 2 on timeout,
 * and -1 on error.
 * ----------------------------------------------------------------------
 */
static int s_sync(synth_t *s, sync_par_t par, int timeout)
{
    assert(s->state->initialized);

    return 1;
}


/*
 * ----------------------------------------------------------------------
 * Get a synthesizer parameter.
 * ----------------------------------------------------------------------
 */
static int s_get_param(struct synth_struct *s, synth_par_t par, int *value)
{
    if (par >= 0 && par < S_MAX) {
	*value = s->state->param[par];
	return 0;
    } else
	return 1;
}


/*
 * ----------------------------------------------------------------------
 * Set a parameter of the synthesizer.
 * ----------------------------------------------------------------------
 */
static int s_set_param(struct synth_struct *s, synth_par_t par, int value)
{
    if (par >= 0 && par < S_MAX) {
	s->state->param[par] = value;
	return 0;
    } else
	return 1;
}
