/*
 * ======================================================================
 * German language module.
 * Copyright Roger Butenuth <butenuth@uni-paderborn.de>
 * Copyright (C) 1998-1999 Roger Butenuth <butenuth@uni-paderborn.de>
 * This is free software, placed under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation.  Please see the file COPYING for details.
 * For the latest version see:
 * http://www.uni-paderborn.de/cs/heiss/blinux/index.html
 * $Id: german.c,v 1.5 1999/03/10 20:37:17 butenuth Exp $
 * ======================================================================
 */
#include <stdio.h>
#include <string.h>
#include <assert.h>
#include "language.h"
#include "german.h"

static int l_close(lang_t *l);
static int l_change_synth(struct lang_struct *l, const char *new_synth);
static int l_speak_string(struct lang_struct *l, unsigned char *buffer);
static int l_get_param(struct lang_struct *l, lang_par_t par, int *value);
static int l_set_param(struct lang_struct *l, lang_par_t par, int value);

typedef struct lang_state {
    int            param[L_MAX];
    int            initialized;
} lang_state_t;

static lang_state_t l_state = {
    { 1 },
    0
};

static lang_t german = {
    &l_state,
    &languages[LANG_GERMAN],
    NULL,
    l_close,
    l_change_synth,
    l_speak_string,
    l_get_param,
    l_set_param
};


/*
 * ----------------------------------------------------------------------
 *
 * ----------------------------------------------------------------------
 */
lang_t *german_open(const char *synth)
{
    synth_t *s;
    assert(!l_state.initialized);

    s = open_synthesizer(synth);
    if (s == NULL)
	return NULL;

    german.synth = s;
    l_state.initialized = 1;

    return &german;
}


/*
 * ----------------------------------------------------------------------
 *
 * ----------------------------------------------------------------------
 */
static int l_close(lang_t *l)
{
    assert(l->state->initialized);

    (*german.synth->close)(german.synth);
    german.synth = NULL;
    l->state->initialized = 0;
    
    return 0;
}


/*
 * ----------------------------------------------------------------------
 *
 * ----------------------------------------------------------------------
 */
static int l_change_synth(struct lang_struct *l, const char *new_synth)
{
    synth_t *s;

    assert(l->state->initialized);
    close_synthesizer(german.synth);
    german.synth = NULL;

    s = open_synthesizer(new_synth);
    if (s == NULL)
	return 1;

    german.synth = s;

    return 0;
}


/*
 * ----------------------------------------------------------------------
 *
 * ----------------------------------------------------------------------
 */
static void handle_other(struct lang_struct *l,
			 unsigned char *buffer, int *i)
{
    unsigned char *str;

    str = german_table[buffer[*i]];
    if (str != NULL)
	german.synth->synth(german.synth, str);
    (*i)++;
}


/*
 * ----------------------------------------------------------------------
 *
 * ----------------------------------------------------------------------
 */
static void handle_punctuation(struct lang_struct *l,
			       unsigned char *buffer, int *pi)
{
    unsigned char my_str[2];

    my_str[0] = buffer[*pi];
    my_str[1] = 0;
    german.synth->synth(german.synth, my_str);

    if (l->state->param[L_SPEAK_PUNCTUATION])
	handle_other(l, buffer, pi);
    else
	(*pi)++;
}


/*
 * ----------------------------------------------------------------------
 *
 * ----------------------------------------------------------------------
 */
static int l_speak_string(struct lang_struct *l, unsigned char *buffer)
{
    int           i;

    assert(l->state->initialized);
    
    i = 0;
    while (buffer[i]) {
	if (strchr(GER_PUNCTUATION, buffer[i])) {
	    handle_punctuation(l, buffer, &i);
	} else {
	    handle_other(l, buffer, &i);
	}
    }
    german.synth->flush(german.synth);

    return 0;
}


/*
 * ----------------------------------------------------------------------
 *
 * ----------------------------------------------------------------------
 */
static int l_get_param(struct lang_struct *l, lang_par_t par, int *value)
{
    if (par >= 0 && par < L_MAX) {
	*value = l->state->param[par];
	return 0;
    } else
	return 1;
}


/*
 * ----------------------------------------------------------------------
 *
 * ----------------------------------------------------------------------
 */
static int l_set_param(struct lang_struct *l, lang_par_t par, int value)
{
    if (par >= 0 && par < L_MAX) {
	l->state->param[par] = value;
	return 0;
    } else
	return 1;
}
