/*
 * ======================================================================
 * Language library. Place for functions and variables that belong
 * nowhere else.
 * Copyright (C) 1998-1999 Roger Butenuth <butenuth@uni-paderborn.de>
 * This is free software, placed under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation.  Please see the file COPYING for details.
 * For the latest version see:
 * http://www.uni-paderborn.de/cs/heiss/blinux/index.html
 * $Id: lang_lib.c,v 1.5 1999/03/10 20:37:19 butenuth Exp $
 * ======================================================================
 */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <dlfcn.h>
#include "synthesizer.h"

synth_t *dummy_synth_open(void);

lang_descr_t languages[LANGUAGES] = {
    { LANG_BRITISH_ENGLISH, "British English" },
    { LANG_GERMAN, "German" },
    { LANG_DUMMY, "no language" }
};


/*
 * ----------------------------------------------------------------------
 *
 * ----------------------------------------------------------------------
 */
synth_t *open_synthesizer(const char *arg)
{
    void       *handle = NULL;
    synth_t    *synth = NULL;
    char       *arg2 = NULL;
    const char *error;
    char       *lib_name, *s_arg;
    synth_t    *(*synth_open)(const char *arg);

    if (arg == NULL) {
	/*
	 * Use the dummy synthesizer.
	 */
	handle = NULL;
	synth = dummy_synth_open();
    } else {
	/*
	 * Copy argument before we change it.
	 */
	arg2 = strdup(arg);
	if (arg2 == NULL)
	    goto failure;
	lib_name = arg2;
	s_arg = strchr(arg2, ' ');
	if (s_arg) {
	    *s_arg = 0;
	    s_arg++;
	} else
	    s_arg = NULL;

	handle = dlopen(lib_name, RTLD_LAZY);
	if (!handle) {
	    fprintf(stderr, "dlopen: %s\n", dlerror());
	    goto failure;
	}
	synth_open = dlsym(handle, "synth_open");
	if ((error = dlerror()) != NULL)  {
	    fputs(error, stderr);
	    goto failure;
	}
	synth = (*synth_open)(s_arg);
	if (synth == NULL) {
	    fprintf(stderr, "synth_open failed\n");
	    goto failure;
	}
	free(arg2);
    }	
    synth->lib_handle = handle;
    return synth;

 failure:
    if (arg2)
	free(arg2);
    if (handle)
	dlclose(handle);
    return NULL;
}


/*
 * ----------------------------------------------------------------------
 * Close synthesizer, close library when synthesizer is in one.
 * ----------------------------------------------------------------------
 */
int close_synthesizer(synth_t *synth)
{
    int  r = 0;
    void *handle;

    handle = synth->lib_handle;
    r = synth->close(synth);
    if (handle != NULL)
	dlclose(handle);
    
    return r;
}
