/*
 * ======================================================================
 * Synthesizer module interface.
 * Copyright (C) 1998-1999 Roger Butenuth <butenuth@uni-paderborn.de>
 * This is free software, placed under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation.  Please see the file COPYING for details.
 * For the latest version see:
 * http://www.uni-paderborn.de/cs/heiss/blinux/index.html
 * $Id: synthesizer.h,v 1.7 1999/03/10 20:37:23 butenuth Exp $
 * ======================================================================
 */
#ifndef _SYNTHESIZER_H
#define _SYNTHESIZER_H

#define LANGUAGES            3

/*
 * Language numbers. Do not change the ordering, some programs rely on
 * this ordering because they index some statically initialized arrays
 * with this language numbers.
 */
#define LANG_BRITISH_ENGLISH 0
#define LANG_GERMAN          1
#define LANG_DUMMY           2


typedef struct {
    int  lang;			/* index (see defines above) */
    char *name;			/* descriptive name */
} lang_descr_t;

extern lang_descr_t languages[LANGUAGES];

typedef enum {
    S_SPEED,			/* 0..n (synth dependent) */
    S_PITCH,			/* 0..n (synth dependent) */
    S_VOLUME,			/* 0..n (synth dependent) */
    S_MAX
} synth_par_t;

typedef enum {
    SYNC_SET,			/* set mark */
    SYNC_POLL,			/* have we reached the mark? */
    SYNC_WAIT,			/* wait for mark */
    SYNC_SET_WAIT		/* set mark and wait (combined) */
} sync_par_t;

typedef struct synth_state *synth_state_p;

typedef struct synth_struct {
    synth_state_p state;
    lang_descr_t  *lang;
    char          *name;
    void          *lib_handle;
    int (*close)(struct synth_struct *s);
    int (*synth)(struct synth_struct *s, unsigned char *buffer);
    int (*flush)(struct synth_struct *s);
    int (*clear)(struct synth_struct *s);
    int (*sync)(struct synth_struct *s, sync_par_t flag, int timeout);
    int (*get_param)(struct synth_struct *s, synth_par_t par, int *value);
    int (*set_param)(struct synth_struct *s, synth_par_t par, int value);
} synth_t;

synth_t *open_synthesizer(const char *arg);
int     close_synthesizer(synth_t *synth);

#endif /* _SYNTHESIZER_H */


