/*
 * BRLTTY - Access software for Unix for a blind person
 *          using a soft Braille terminal
 *
 * Copyright (C) 1995-1998 by The BRLTTY Team, All rights reserved.
 *
 *     Nicolas Pitre <nico@cam.org>
 *     Stphane Doyon <s.doyon@videotron.ca>
 *     Nikhil Nair <nn201@cus.cam.ac.uk>
 * This part by:
 *     Roger Butenuth <butenuth@uni-paderborn.de>
 *
 * BRLTTY comes with ABSOLUTELY NO WARRANTY.
 *
 * This is free software, placed under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation.  Please see the file COPYING for details.
 *
 * $Id: config_file.h,v 1.5 1999/03/10 20:38:56 butenuth Exp $
 */
#ifndef _CONFIG_FILE_H
#define _CONFIG_FILE_H

/*
 * The configuration language:
 *
 * language ::= [item]
 * item ::= assignment | braille_driver | speech_driver
 * brl_drv_val ::= "braille" "{" assign_list "}"
 * speech_drv_val ::= "speech" "{" assign_list "}"
 * assign_list ::= [assignment]
 * assignment ::= <symbol> "=" value
 * value ::= <string> | brl_drv_val | speech_drv_val
 * braille_driver ::= "braille_driver" "=" <symbol>
 * speech_driver ::= "speech_driver" "=" <symbol>
 */

typedef enum {
    T_EOF, T_INTEGER, T_SYMBOL, T_STRING,
    T_EQUAL, T_LEFT_BRACE, T_RIGHT_BRACE,
    T_BRAILLE, T_BRAILLE_DRIVER, 
    T_SPEECH, T_SPEECH_DRIVER
} tnum_t;

typedef struct {
    tnum_t    tnum;
    int line, column;
    union {
	int  intval;
	int  key;
	char *symval;
	char *stringval;
    } u;
} token_t;

typedef struct symbol_struct {
    struct symbol_struct *next;
    struct scope_struct  *scope;
    char *name;
    int  line;			/* line of definition */
    enum {
	SY_STRINGVAR, SY_BRL_DRV, SY_SPEECH_DRV
    } type;
    union {
	char *stringval;
	struct brl_drv_struct *brl_drv;
	struct speech_drv_struct *speech_drv;
    } u;
} symbol_t;

typedef struct scope_struct {
    struct scope_struct *pred;	/* static predecessor */
    symbol_t            *sym;	/* list of symbol in this scope */
} scope_t;

typedef struct brl_drv_struct {
    scope_t *scope;
} brl_drv_t;

typedef struct speech_drv_struct {
    scope_t *scope;
} speech_drv_t;


/* not really used */
typedef struct item_struct {
    struct item_struct *next;
    enum {
	IT_
    } type;
    union {
	int dummy;
    } u;
} item_t;

typedef struct {
    char         *filename;
    scope_t      *scope;
    brl_drv_t    *brl_drv;
    speech_drv_t *speech_drv;
} syntax_tree_t;

int  parse_config_file(const char *file, syntax_tree_t **tree_p);
int  free_syntax_tree(syntax_tree_t *tree);
symbol_t *lookup_symbol(scope_t *scope, const char *name);

#endif /* _CONFIG_FILE_H */
