/*
 * BRLTTY - Access software for Unix for a blind person
 *          using a soft Braille terminal
 *
 * Copyright (C) 1995-1998 by The BRLTTY Team, All rights reserved.
 *
 *     Nicolas Pitre <nico@cam.org>
 *     Stphane Doyon <s.doyon@videotron.ca>
 *     Nikhil Nair <nn201@cus.cam.ac.uk>
 * This part completely rewritten by:
 *     Roger Butenuth <butenuth@uni-paderborn.de>
 *
 * BRLTTY comes with ABSOLUTELY NO WARRANTY.
 *
 * This is free software, placed under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation.  Please see the file COPYING for details.
 *
 * This software is maintained by Nicolas Pitre <nico@cam.org>.
 */

#ifndef _SCR_H
#define _SCR_H

/* mode argument for getscr () */
#define SCR_TEXT   0		/* get screen text */
#define SCR_ATTRIB 1		/* get screen attributes */

/* disp argument for selectdisp () */
#define LIVE_SCRN 0		/* read the physical screen */
#define FROZ_SCRN 1		/* read frozen screen image */

/* blocking and non blocking event reading */
#define EVNT_BLOCKING     1
#define EVNT_NON_BLOCKING 0


typedef struct {
    short rows, cols;		/* screen dimensions */
    short posx, posy;		/* cursor position */
    short no;			/* screen number */
} scrstat_t;

typedef struct {
    short left, top;		/* coordinates of corner, counting from 0 */
    short width, height;	/* dimensions */
} winpos_t;


int  init_screen(void);		/* initialise screen reading functions */
void close_screen(void);	/* close screen reading */

void getstat(scrstat_t *);	/* get screen status */
unsigned char *getscr(winpos_t pos, unsigned char *buffer, short mode);
		/* Read a rectangle from the screen - text or attributes: */

int  selectdisp(int);		/* select display page */
void sethlpscr(int model);

int get_input_event(int type, int blocking);
void cursor_routing(int curscr, int x, int y);

void inskey(int fd, unsigned char *string);

/* cut'n'paste functionality */
void cut_begin(int x, int y);
void cut_end(int x, int y);
void cut_paste(void);

#endif /* !_SCR_H */
