/*
 * BRLTTY - Access software for Unix for a blind person
 *          using a soft Braille terminal
 *
 * Copyright (C) 1998 by The BRLTTY Team, All rights reserved.
 *
 * This part from:
 *     Roger Butenuth <butenuth@uni-paderborn.de>
 *
 * BRLTTY comes with ABSOLUTELY NO WARRANTY.
 *
 * This is free software, placed under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation.  Please see the file COPYING for details.
 *
 * $Id: setup.h,v 1.10 1999/03/01 20:26:20 butenuth Exp $
 */
#ifndef _SETUP_H
#define _SETUP_H

#include "brl.h"

#define TXT_LEN 40

typedef struct msg_struct {
    char txt[LANGUAGES][TXT_LEN];
} msg_t;

typedef enum { 
    C_GET_VALUE,
    C_SET_VALUE,
    C_UP,
    C_DOWN
} cmd_e;

typedef void (*entry_f)(void *this, cmd_e cmd, msg_t *text, int *value);

typedef enum { N_MENU, N_ENTRY } node_e;

typedef union node_union node_t;
typedef struct menu_struct menu_t;
typedef struct entry_struct entry_t;

struct menu_struct {
    node_e type;		/* for union discrimination */
    msg_t  *title;		/* of this menu */
    int    no_entries;		/* number of sub entries */
    int    alloc_entries;	/* allocated space for entries */
    int    cur;			/* currently active entry */
    node_t **entry;		/* array with entries, 0 is parent */
};

struct entry_struct {
    node_e  type;		/* for union discrimination */
    msg_t   *name;		/* of this entry */
    entry_f fun;		/* handler function */
    void    *private;		/* "this" pointer for handler function */
};

union node_union {
    node_e  type;
    menu_t  m;
    entry_t e;
};

typedef struct binary_struct {
    int     *value;		/* pointer to 0 or 1 value */
    entry_t *entry;		/* pointer entry this belongs to */
    msg_t   *text[2];		/* text for value [0, 1] */
} binary_t;

typedef struct integer_struct {
    int     *value;		/* pointer to 0 or 1 value */
    int     min, max;		/* lower and upper limit */
    int     wrap;		/* wraparound at interval limits? */
    entry_t *entry;		/* pointer entry this belongs to */
} integer_t;

void init_setup(void);
void setup(int curscr, brltty_param_t *p);
int  save_setup(const char *filename);
int  load_setup(const char *filename);
menu_t *make_menu(msg_t *title, node_t *parent);
void   add_to_menu(menu_t *menu, node_t *node);
void   add_bin_to_menu(menu_t *menu, msg_t *title, int *value,
		       msg_t *zero_text, msg_t *one_text);
void   add_itg_to_menu(menu_t *menu, msg_t *title, int *value,
		       int min, int max, int wrap);

extern int s_csrvis, s_attrvis, s_csrblink, s_capblink, s_attrblink,
    s_csrsize, s_csroncnt, s_csroffcnt, s_caponcnt, s_capoffcnt,
    s_attroncnt, s_attroffcnt, s_sixdots, s_slidewin, s_speech,
    s_skip_id_lines;

#endif /* _SETUP_H */
